Class: RSpec::Mocks::AnyInstance::Chain
- Inherits:
-
Object
- Object
- RSpec::Mocks::AnyInstance::Chain
- Defined in:
- lib/rspec/mocks/any_instance/chain.rb
Direct Known Subclasses
Instance Method Summary collapse
-
#and_raise(*args, &block) ⇒ Object
Records the
and_raisemessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#and_return(*args, &block) ⇒ Object
Records the
and_returnmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#and_throw(*args, &block) ⇒ Object
Records the
and_throwmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#and_yield(*args, &block) ⇒ Object
Records the
and_yieldmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#any_number_of_times(*args, &block) ⇒ Object
Records the
any_number_of_timesmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#at_least(*args, &block) ⇒ Object
Records the
at_leastmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#at_most(*args, &block) ⇒ Object
Records the
at_mostmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#exactly(*args, &block) ⇒ Object
Records the
exactlymessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#never(*args, &block) ⇒ Object
Records the
nevermessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#once(*args, &block) ⇒ Object
Records the
oncemessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#times(*args, &block) ⇒ Object
Records the
timesmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#twice(*args, &block) ⇒ Object
Records the
twicemessage for playback against an instance that invokes a method stubbed or mocked usingany_instance. -
#with(*args, &block) ⇒ Object
Records the
withmessage for playback against an instance that invokes a method stubbed or mocked usingany_instance.
Instance Method Details
#and_raise(*args, &block) ⇒ Object
Records the and_raise message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
25 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 25 record :and_raise |
#and_return(*args, &block) ⇒ Object
Records the and_return message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
24 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 24 record :and_return |
#and_throw(*args, &block) ⇒ Object
Records the and_throw message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
26 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 26 record :and_throw |
#and_yield(*args, &block) ⇒ Object
Records the and_yield message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
27 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 27 record :and_yield |
#any_number_of_times(*args, &block) ⇒ Object
Records the any_number_of_times message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
31 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 31 record :any_number_of_times |
#at_least(*args, &block) ⇒ Object
Records the at_least message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
35 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 35 record :at_least |
#at_most(*args, &block) ⇒ Object
Records the at_most message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
36 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 36 record :at_most |
#exactly(*args, &block) ⇒ Object
Records the exactly message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
32 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 32 record :exactly |
#never(*args, &block) ⇒ Object
Records the never message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
34 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 34 record :never |
#once(*args, &block) ⇒ Object
Records the once message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
29 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 29 record :once |
#times(*args, &block) ⇒ Object
Records the times message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
33 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 33 record :times |
#twice(*args, &block) ⇒ Object
Records the twice message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
30 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 30 record :twice |
#with(*args, &block) ⇒ Object
Records the with message for playback against an instance that
invokes a method stubbed or mocked using any_instance.
28 |
# File 'lib/rspec/mocks/any_instance/chain.rb', line 28 record :with |